==> gameap-3.1-shared.zip: upload/resources/lang/en/labels.php <==
<?php

return [
    // Main
    'name' => 'Name',
    'the_value' => 'Value',

    // ClientCertificates
    'private_key_pass' => 'Private Key Password',

    // DedicatedServer
    'enabled' => 'Enabled',
    'os' => 'Operating system',
    'location' => 'Location',
    'provider' => 'Provider',
    'ip' => 'IP',
    'ram' => 'RAM',
    'cpu' => 'CPU',
    'work_path' => 'Work Path',
    'steamcmd_path' => 'SteamCMD Path',
    'gdaemon_host' => 'GDaemon Host',
    'gdaemon_port' => 'GDaemon Port',
    'gdaemon_api_key' => 'GDaemon API Key',
    'gdaemon_api_token' => 'GDaemon API Token',
    'gdaemon_login' => 'GDaemon Login',
    'gdaemon_password' => 'GDaemon Password',
    'gdaemon_server_cert' => 'GDaemon Server Certificate',
    'client_certificate_id' => 'GDaemon Certificate',
    'prefer_install_method' => 'Prefer Installation Method',
    'script_install' => 'Script Install',
    'script_reinstall' => 'Script Reinstall',
    'script_update' => 'Script Update',
    'script_start' => 'Script Start',
    'script_pause' => 'Script Pause',
    'script_unpause' => 'Script Unpause',
    'script_stop' => 'Script Stop',
    'script_restart' => 'Script Restart',
    'script_status' => 'Script Status',
    'script_stats' => 'Script Stats',
    'script_get_console' => 'Script Get Console',
    'script_send_command' => 'Script Send Command',
    'script_delete' => 'Script Delete',

    // Game
    'code' => 'Code',
    'start_code' => 'Start Code',
    'engine' => 'Engine',
    'engine_version' => 'Engine Version',
    'steam_app_id_linux' => 'Steam App ID (Linux)',
    'steam_app_id_windows' => 'Steam App ID (Windows)',
    'steam_app_set_config' => 'Steam App Set Config',

    // GameMod
    'game_code' => 'Game Code',
    'fast_rcon' => 'Fast RCON',
    'vars' => 'Vars',
    'remote_repository_linux' => 'Remote Repository (Linux)',
    'remote_repository_windows' => 'Remote Repository (Windows)',
    'local_repository_linux' => 'Local Repository (Linux)',
    'local_repository_windows' => 'Local Repository (Windows)',
    'kick_cmd' => 'Kick Command',
    'ban_cmd' => 'Ban Command',
    'chname_cmd' => 'Change Name Command',
    'srestart_cmd' => 'Server Restart Command',
    'chmap_cmd' => 'Change Map Command',
    'sendmsg_cmd' => 'Send Message Command',
    'passwd_cmd' => 'Set/Change Password Command',
    'start_cmd_linux' => 'Start Command (Linux)',
    'start_cmd_windows' => 'Start Command (Windows)',

    // Server
    'game_server' => 'Game server',
    'installed' => 'Installed',
    'blocked' => 'Blocked',
    'uuid' => 'UUID',
    'uuid_short' => 'Short UUID',
    'ds_id' => 'Dedicated Server',
    'game_mod_id' => 'Game Mod',
    'expires' => 'Expires',
    'server_port' => 'Server Port',
    'query_port' => 'Query Port',
    'rcon_port' => 'RCON Port',

    // TODO: Replace to rcon_password
    'rcon' => 'RCON Password',
    'dir' => 'Dir',
    'su_user' => 'Su User',
    'cpu_limit' => 'CPU Limit',
    'ram_limit' => 'RAM Limit',
    'net_limit' => 'NET Limit',
    'start_command' => 'Start Command',
    'stop_command' => 'Stop Command',
    'force_stop_command' => 'Force Stop Command',
    'restart_command' => 'Restart Command',

    // User
    'login' => 'Login',
    'current_password' => 'Current Password',
    'password' => 'Password',
    'password_confirmation' => 'Password Confirmation',
    'roles' => 'Roles',
    'token_name' => 'Token Name',

    // Generic servers
    'host' => 'Host',
    'port' => 'Port',
    'username' => 'UserName',
];

==> gameap-3.2-shared.zip: upload/resources/lang/en/labels.php <==
<?php

return [
    // Main
    'name' => 'Name',
    'the_value' => 'Value',

    // ClientCertificates
    'private_key_pass' => 'Private Key Password',

    // DedicatedServer
    'enabled' => 'Enabled',
    'os' => 'Operating system',
    'location' => 'Location',
    'provider' => 'Provider',
    'ip' => 'IP',
    'ram' => 'RAM',
    'cpu' => 'CPU',
    'work_path' => 'Work Path',
    'steamcmd_path' => 'SteamCMD Path',
    'gdaemon_host' => 'GDaemon Host',
    'gdaemon_port' => 'GDaemon Port',
    'gdaemon_api_key' => 'GDaemon API Key',
    'gdaemon_api_token' => 'GDaemon API Token',
    'gdaemon_login' => 'GDaemon Login',
    'gdaemon_password' => 'GDaemon Password',
    'gdaemon_server_cert' => 'GDaemon Server Certificate',
    'client_certificate_id' => 'GDaemon Client Certificate',
    'prefer_install_method' => 'Prefer Installation Method',
    'script_install' => 'Script Install',
    'script_reinstall' => 'Script Reinstall',
    'script_update' => 'Script Update',
    'script_start' => 'Script Start',
    'script_pause' => 'Script Pause',
    'script_unpause' => 'Script Unpause',
    'script_stop' => 'Script Stop',
    'script_kill' => 'Script Kill',
    'script_restart' => 'Script Restart',
    'script_status' => 'Script Status',
    'script_stats' => 'Script Stats',
    'script_get_console' => 'Script Get Console',
    'script_send_command' => 'Script Send Command',
    'script_delete' => 'Script Delete',

    // Game
    'code' => 'Code',
    'start_code' => 'Start Code',
    'engine' => 'Engine',
    'engine_version' => 'Engine Version',
    'steam_app_id_linux' => 'Steam App ID (Linux)',
    'steam_app_id_windows' => 'Steam App ID (Windows)',
    'steam_app_set_config' => 'Steam App Set Config',

    // GameMod
    'game_code' => 'Game Code',
    'fast_rcon' => 'Fast RCON',
    'vars' => 'Vars',
    'remote_repository_linux' => 'Remote Repository (Linux)',
    'remote_repository_windows' => 'Remote Repository (Windows)',
    'local_repository_linux' => 'Local Repository (Linux)',
    'local_repository_windows' => 'Local Repository (Windows)',
    'kick_cmd' => 'Kick Command',
    'ban_cmd' => 'Ban Command',
    'chname_cmd' => 'Change Name Command',
    'srestart_cmd' => 'Server Restart Command',
    'chmap_cmd' => 'Change Map Command',
    'sendmsg_cmd' => 'Send Message Command',
    'passwd_cmd' => 'Set/Change Password Command',
    'start_cmd_linux' => 'Start Command (Linux)',
    'start_cmd_windows' => 'Start Command (Windows)',

    // Server
    'game_server' => 'Game server',
    'installed' => 'Installed',
    'blocked' => 'Blocked',
    'uuid' => 'UUID',
    'uuid_short' => 'Short UUID',
    'ds_id' => 'Dedicated Server',
    'game_id' => 'Game',
    'game_mod_id' => 'Game Mod',
    'expires' => 'Expires',
    'server_port' => 'Server Port',
    'query_port' => 'Query Port',
    'rcon_port' => 'RCON Port',

    // TODO: Replace to rcon_password
    'rcon' => 'RCON Password',
    'dir' => 'Dir',
    'su_user' => 'Su User',
    'cpu_limit' => 'CPU Limit',
    'ram_limit' => 'RAM Limit',
    'net_limit' => 'NET Limit',
    'start_command' => 'Start Command',
    'stop_command' => 'Stop Command',
    'force_stop_command' => 'Force Stop Command',
    'restart_command' => 'Restart Command',

    // User
    'login' => 'Login',
    'email' => 'Email',
    'current_password' => 'Current Password',
    'new_password' => 'New Password',
    'password' => 'Password',
    'password_confirmation' => 'Password Confirmation',
    'roles' => 'Roles',
    'token_name' => 'Token Name',

    // Generic servers
    'host' => 'Host',
    'port' => 'Port',
    'username' => 'UserName',
];
